@@ -38,7 +38,7 @@ maintainer = "Massimo Capodiferro"
 
 maintainer_email = "massimo.capodiferro@ansys.com"
 
-description = "Higher-Level Pythonic Ansys Electronics Destkop Framework"
+description = "Higher-Level Pythonic Ansys Electronics Desktop Framework"
 
 # Get the long description from the README file
 with open3(os.path.join(HERE, "README.rst"), encoding="utf-8") as f:
@@ -73,6 +73,7 @@ data_files = [
     ("dlls", recursive_glob(os.path.join("pyaedt", "dlls"), "*")),
     ("misc", recursive_glob(os.path.join("pyaedt", "misc"), "*")),
     ("License", recursive_glob(".", "*.md")),
+    ("xaml", ["pyaedt/generic/wpf_template.xaml"]),
     ("version", ["pyaedt/version.txt"]),
     ("setup-distutils", ["setup-distutils.py"]),
 ]
