@@ -4,19 +4,18 @@ import os
 
 os.environ["ANSYSEM_FEATURE_SF6694_NON_GRAPHICAL_COMMAND_EXECUTION_ENABLE"] = "1"
 os.environ["ANSYSEM_FEATURE_SF159726_SCRIPTOBJECT_ENABLE"] = "1"
-
-
-try:
+__version__ = ""
+if os.path.exists(os.path.join(os.path.dirname(__file__), "version.txt")):
     with open(os.path.join(os.path.dirname(__file__), "version.txt"), "r") as f:
         __version__ = f.read().strip()
-except:
-    __version__ = ""
 
+from pyaedt.generic.general_methods import settings
 from pyaedt.generic import constants
 from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name, _retry_ntimes
 from pyaedt.generic.general_methods import is_ironpython, _pythonver, inside_desktop, convert_remote_object
 from pyaedt.aedt_logger import AedtLogger
 
+
 try:
     from pyaedt.generic.design_types import Hfss3dLayout
 except:
@@ -32,6 +31,7 @@ from pyaedt.generic.design_types import (
     Edb,
     Maxwell3d,
     Maxwell2d,
+    MaxwellCircuit,
     Mechanical,
     Rmxprt,
     TwinBuilder,
