@@ -1,4 +1,5 @@
 import os
+import warnings
 
 from pyaedt.generic.general_methods import aedt_exception_handler, is_ironpython
 from pyaedt.modeler.Model3DLayout import Modeler3DLayout
@@ -87,7 +88,7 @@ class FieldAnalysis3DLayout(Analysis):
         self._oboundary = self._odesign.GetModule("Excitations")
         self.logger.info("Analysis Loaded")
         self._modeler = Modeler3DLayout(self)
-        self._modeler.primitives.init_padstacks()
+        self._modeler.init_padstacks()
         self.logger.info("Modeler Loaded")
         self._mesh = Mesh3d(self)
         self._post = PostProcessor(self)
@@ -136,10 +137,30 @@ class FieldAnalysis3DLayout(Analysis):
         """
         return self._mesh
 
+    @property
+    def excitations(self):
+        """Excitation names.
+
+        Returns
+        -------
+        list
+            List of excitation names. Excitations with multiple modes will return one
+            excitation for each mode.
+
+        References
+        ----------
+
+        >>> oModule.GetExcitations
+        """
+        return list(self.oboundary.GetAllPortsList())
+
     @property
     def get_excitations_name(self):
         """Excitation names.
 
+        .. deprecated:: 0.4.27
+           Use :func:`excitations` property instead.
+
         Returns
         -------
         list
@@ -150,7 +171,8 @@ class FieldAnalysis3DLayout(Analysis):
 
         >>> oModule.GetAllPortsList
         """
-        return list(self.oboundary.GetAllPortsList())
+        warnings.warn("`get_excitations_name` is deprecated. Use `excitations` property instead.", DeprecationWarning)
+        return self.excitations
 
     @property
     def get_all_sparameter_list(self, excitation_names=[]):
@@ -171,7 +193,7 @@ class FieldAnalysis3DLayout(Analysis):
 
         """
         if not excitation_names:
-            excitation_names = self.get_excitations_name
+            excitation_names = self.excitations
         spar = []
         k = 0
         for i in excitation_names:
@@ -234,7 +256,7 @@ class FieldAnalysis3DLayout(Analysis):
         >>> oModule.GetAllPorts
         """
         if not excitation_names:
-            excitation_names = self.get_excitations_name
+            excitation_names = self.excitations
         if excitation_name_prefix:
             excitation_names = [i for i in excitation_names if excitation_name_prefix.lower() in i.lower()]
         spar = []
@@ -271,9 +293,9 @@ class FieldAnalysis3DLayout(Analysis):
         """
         spar = []
         if not trlist:
-            trlist = [i for i in self.get_excitations_name if tx_prefix in i]
+            trlist = [i for i in self.excitations if tx_prefix in i]
         if not reclist:
-            reclist = [i for i in self.get_excitations_name if rx_prefix in i]
+            reclist = [i for i in self.excitations if rx_prefix in i]
         if len(trlist) != len(reclist):
             self.logger.error("The TX and RX lists should be same length.")
             return False
@@ -305,7 +327,7 @@ class FieldAnalysis3DLayout(Analysis):
         """
         next = []
         if not trlist:
-            trlist = [i for i in self.get_excitations_name if tx_prefix in i]
+            trlist = [i for i in self.excitations if tx_prefix in i]
         for i in trlist:
             k = trlist.index(i) + 1
             while k < len(trlist):
@@ -346,9 +368,9 @@ class FieldAnalysis3DLayout(Analysis):
         """
         fext = []
         if not trlist:
-            trlist = [i for i in self.get_excitations_name if tx_prefix in i]
+            trlist = [i for i in self.excitations if tx_prefix in i]
         if not reclist:
-            reclist = [i for i in self.get_excitations_name if rx_prefix in i]
+            reclist = [i for i in self.excitations if rx_prefix in i]
         for i in trlist:
             for k in reclist:
                 if not skip_same_index_couples or reclist.index(k) != trlist.index(i):
