@@ -165,6 +165,24 @@ class EDBPrimitives(object):
         self._core_net = core_app.core_nets
         self.primitive_object = raw_primitive
 
+    @aedt_exception_handler
+    def area(self, include_voids=True):
+        """Return the total area.
+
+        Parameters
+        ----------
+        include_voids : bool, optional
+            Either if the voids have to be included in computation.
+        Returns
+        -------
+        float
+        """
+        area = self.primitive_object.GetPolygonData().Area()
+        if include_voids:
+            for el in self.primitive_object.Voids:
+                area -= el.GetPolygonData().Area()
+        return area
+
     @property
     def is_void(self):
         """Either if the primitive is a void or not.
@@ -237,7 +255,7 @@ class EDBPrimitives(object):
         yr = []
         for i in range(n):
             i += 1
-            dth = (i/(n+1)) * th
+            dth = (float(i)/(n+1)) * th
             xi = xc + r * math.cos(alpha-dth)
             yi = yc + r * math.sin(alpha-dth)
             xr.append(xi)
@@ -1091,6 +1109,14 @@ class EDBLayers(object):
                 )
                 newLayer = self._edb_object[layerName].set_elevation(newLayer, el)
                 el += newLayer.GetThickness()
+            for lyr in layers:
+                if not lyr.IsStackupLayer():
+                    newLayers.Add(lyr.Clone())
+                    continue
+                newLayer = lyr.Clone()
+                newLayer = self._edb_object[lyr.GetName()].set_elevation(newLayer, el)
+                el += newLayer.GetThickness()
+                newLayers.Add(newLayer)
         else:
             for lyr in layers:
                 if not lyr.IsStackupLayer():
@@ -1272,6 +1298,35 @@ class EDBPadProperties(object):
             params = [val, val, val]
         self._update_pad_parameters_parameters(geom_type=geom_type, params=params)
 
+    @property
+    def parameters_values(self):
+        """Parameters.
+
+        Returns
+        -------
+        list
+            List of parameters.
+        """
+        pad_values = self._padstack_methods.GetPadParametersValue(self._edb_padstack, self.layer_name, self.pad_type)
+        return [i.ToDouble() for i in pad_values.Item2]
+
+    @property
+    def polygon_data(self):
+        """Parameters.
+
+        Returns
+        -------
+        list
+            List of parameters.
+        """
+        try:
+            pad_values = self._padstack_methods.GetPolygonalPadParameters(
+                self._edb_padstack, self.layer_name, self.pad_type
+            )
+            return pad_values.Item1
+        except:
+            return
+
     @property
     def parameters(self):
         """Parameters.
@@ -1772,6 +1827,11 @@ class EDBPadstackInstance(object):
         self._edb_padstackinstance = edb_padstackinstance
         self._pedb = _pedb
 
+    @property
+    def pin(self):
+        """Return Edb padstack object."""
+        return self._edb_padstackinstance
+
     @property
     def padstack_definition(self):
         """Padstack definition.
@@ -1948,7 +2008,7 @@ class EDBPadstackInstance(object):
             pin_name = self._edb_padstackinstance.GetName()
             return "-".join([comp_name, pin_name])
         else:
-            return None
+            return self._edb_padstackinstance.GetName()
 
     @aedt_exception_handler
     def delete_padstack_instance(self):
@@ -1980,38 +2040,6 @@ class EDBPadstackInstance(object):
                 voids.append(prim)
         return voids
 
-
-class EDBPinInstances(object):
-    """Manages EDB functionalities in instances.
-
-
-    Examples
-    --------
-    >>> from pyaedt import Edb
-    >>> edb = Edb(myedb, edbversion="2021.2")
-    >>> edb_pin_instance = edb.core_components.components["R1"].pins[0]
-    """
-
-    def __init__(self, edb_components, pin):
-        self._pedbcomponents = edb_components
-        self.pin = pin
-
-    @property
-    def placement_layer(self):
-        """Placement layer."""
-        return self.pin.GetGroup().GetPlacementLayer().GetName()
-
-    @property
-    def net(self):
-        """Net.
-
-        Returns
-        -------
-        str
-           Name of the net.
-        """
-        return self.pin.GetNet().GetName()
-
     @property
     def pingroups(self):
         """Pin groups that the pin belongs to.
@@ -2021,55 +2049,7 @@ class EDBPinInstances(object):
         list
             List of pin groups that the pin belongs to.
         """
-        return self.pin.GetPinGroups()
-
-    @property
-    def position(self):
-        """Pin position.
-
-        Returns
-        -------
-        list
-            List of ``[x, y]``` coordinates for the pin position.
-        """
-        self._pedbcomponents._edb.Geometry.PointData(
-            self._pedbcomponents._edb_value(0.0), self._pedbcomponents._edb_value(0.0)
-        )
-        if is_ironpython:
-            out = self.pin.GetPositionAndRotationValue()
-        else:
-            out = self.pin.GetPositionAndRotationValue(
-                self._pedbcomponents._edb.Geometry.PointData(
-                    self._pedbcomponents._edb_value(0.0), self._pedbcomponents._edb_value(0.0)
-                ),
-                self._pedbcomponents._edb_value(0.0),
-            )
-        if out[0]:
-            return [out[1].X.ToDouble(), out[1].Y.ToDouble()]
-
-    @property
-    def rotation(self):
-        """Pin rotation.
-
-        Returns
-        -------
-        float
-            Rotatation value for the pin.
-        """
-        self._pedbcomponents._edb.Geometry.PointData(
-            self._pedbcomponents._edb_value(0.0), self._pedbcomponents._edb_value(0.0)
-        )
-        if is_ironpython:
-            out = self.pin.GetPositionAndRotationValue()
-        else:
-            out = self.pin.GetPositionAndRotationValue(
-                self._pedbcomponents._edb.Geometry.PointData(
-                    self._pedbcomponents._edb_value(0.0), self._pedbcomponents._edb_value(0.0)
-                ),
-                self._pedbcomponents._edb_value(0.0),
-            )
-        if out[0]:
-            return out[2].ToDouble()
+        return self._edb_padstackinstance.GetPinGroups()
 
     @property
     def placement_layer(self):
@@ -2080,7 +2060,7 @@ class EDBPinInstances(object):
         str
             Name of the placement layer.
         """
-        return self.pin.GetGroup().GetPlacementLayer().GetName()
+        return self._edb_padstackinstance.GetGroup().GetPlacementLayer().GetName()
 
     @property
     def lower_elevation(self):
@@ -2091,7 +2071,7 @@ class EDBPinInstances(object):
         float
             Lower elavation of the placement layer.
         """
-        return self.pin.GetGroup().GetPlacementLayer().GetLowerElevation()
+        return self._edb_padstackinstance.GetGroup().GetPlacementLayer().GetLowerElevation()
 
     @property
     def upper_elevation(self):
@@ -2102,7 +2082,7 @@ class EDBPinInstances(object):
         float
            Upper elevation of the placement layer.
         """
-        return self.pin.GetGroup().GetPlacementLayer().GetUpperElevation()
+        return self._edb_padstackinstance.GetGroup().GetPlacementLayer().GetUpperElevation()
 
     @property
     def top_bottom_association(self):
@@ -2119,7 +2099,7 @@ class EDBPinInstances(object):
             * 4 Number of top/bottom association type.
             * -1 Undefined.
         """
-        return int(self.pin.GetGroup().GetPlacementLayer().GetTopBottomAssociation())
+        return int(self._edb_padstackinstance.GetGroup().GetPlacementLayer().GetTopBottomAssociation())
 
 
 class EDBComponent(object):
@@ -2225,6 +2205,19 @@ class EDBComponent(object):
                 return pair.IsParallel
         return None
 
+    @property
+    def center(self):
+        """Compute the component center.
+
+        Returns
+        -------
+        list
+        """
+        layinst = self.edbcomponent.GetLayout().GetLayoutInstance()
+        cmpinst = layinst.GetLayoutObjInstance(self.edbcomponent, None)
+        center = cmpinst.GetCenter()
+        return [center.X.ToDouble(), center.Y.ToDouble()]
+
     @property
     def pinlist(self):
         """Pins of Component.
@@ -2257,16 +2250,16 @@ class EDBComponent(object):
 
     @property
     def pins(self):
-        """EDBPinInstances of Component.
+        """EDBPadstackInstance of Component.
 
         Returns
         -------
-        list
-            List of EDBPinInstances of Component.
+        dic[str, :class:`pyaedt.edb_core.EDB_Data.EDBPadstackInstance`]
+            Dictionary of EDBPadstackInstance Components.
         """
         pins = {}
         for el in self.pinlist:
-            pins[el.GetName()] = EDBPinInstances(self, el)
+            pins[el.GetName()] = EDBPadstackInstance(el, self._pcomponents._pedb)
         return pins
 
     @property
