@@ -6,8 +6,9 @@ from __future__ import absolute_import
 
 import logging
 import warnings
+import os
 
-from ..generic.general_methods import aedt_exception_handler
+from pyaedt.generic.general_methods import aedt_exception_handler
 
 try:
     import clr
@@ -15,18 +16,19 @@ try:
     clr.AddReference("System.Collections")
     from System.Collections.Generic import List
 except ImportError:
-    warnings.warn("This module requires pythonnet.")
+    if os.name != "posix":
+        warnings.warn("This module requires pythonnet.")
 
 logger = logging.getLogger(__name__)
 
 
 @aedt_exception_handler
-def convert_netdict_to_pydict(dict):
+def convert_netdict_to_pydict(dict_in):
     """Convert a net dictionary to a Python dictionary.
 
     Parameters
     ----------
-    dict : dict
+    dict_in : dict
         Net dictionary to convert.
 
     Returns
@@ -36,8 +38,8 @@ def convert_netdict_to_pydict(dict):
 
     """
     pydict = {}
-    for key in dict.Keys:
-        pydict[key] = dict[key]
+    for key in dict_in.Keys:
+        pydict[key] = dict_in[key]
     return pydict
 
 
@@ -74,7 +76,7 @@ def convert_py_list_to_net_list(pylist):
     list
         List converted to Net.
     """
-    if type(pylist) is not list and type(pylist) is not tuple:
+    if not isinstance(pylist, (list, tuple)):
         pylist = [pylist]
     ls = list([type(item) for item in pylist])
     if len(ls) > 0:
