@@ -2,7 +2,7 @@ import math
 import os
 import re
 
-from .general_methods import aedt_exception_handler
+from pyaedt.generic.general_methods import aedt_exception_handler
 
 REAL_IMAG = "RI"
 MAG_ANGLE = "MA"
