@@ -11,6 +11,8 @@ from functools import wraps
 from collections import OrderedDict
 import inspect
 import itertools
+import re
+import fnmatch
 
 try:
     logger = logging.getLogger("Global")
@@ -43,7 +45,7 @@ def _write_mes(mes_text):
     if logger:
         for el in parts:
             logger.error(el)
-    elif os.getenv("PYAEDT_SCREEN_LOGS", "True").lower() in ("true", "1", "t"):
+    elif settings.enable_screen_logs:
         for el in parts:
             print(el)
 
@@ -134,14 +136,24 @@ def convert_remote_object(arg):
     """
     if _check_types(arg) == "list":
         if arg.__len__() > 0:
-            if isinstance(arg[0], (int, float, str, dict)):
-                return list(eval(str(arg)))
+            if (
+                isinstance(arg[0], (int, float, str))
+                or _check_types(arg[0]) == "list"
+                or _check_types(arg[0]) == "dict"
+            ):
+                a = list(eval(str(arg)))
+                for i, el in enumerate(a):
+                    a[i] = convert_remote_object(el)
+                return a
             else:
                 return [arg[i] for i in range(arg.__len__())]
         else:
             return []
     elif _check_types(arg) == "dict":
-        return dict(eval(str(arg)))
+        a = dict(eval(str(arg)))
+        for k, v in a.items():
+            a[k] = convert_remote_object(v)
+        return a
     return arg
 
 
@@ -169,34 +181,45 @@ def _remote_dict_conversion(args):
 
 
 def _log_method(func, new_args, new_kwargs):
-    if str(func.__name__)[0] != "_":
-        line_begin = "    Implicit Arguments: "
-        line_begin2 = "    Explicit Arguments: "
-        message = []
-        if new_args:
-            object_name = str([new_args[0]])[1:-1]
-            id = object_name.find(" object at ")
-            if id >= 0:
-                object_name = object_name[1:id]
-                message.append(" '{}' has been exectuted.".format(object_name + "." + str(func.__name__)))
-                if new_args[1:]:
-                    message.append(line_begin + str(new_args[1:])[1:-1])
-                if new_kwargs:
-                    message.append(line_begin2 + str(new_kwargs)[1:-1])
-
-            else:
-                message.append(" '{}' has been exectuted.".format(str(func.__name__)))
-                if new_args[1:]:
-                    message.append(line_begin + str(new_args[1:])[1:-1])
-                if new_kwargs:
-                    message.append(line_begin2 + str(new_kwargs)[1:-1])
-
-        else:
-            message.append(" '{}' has been exectuted".format(str(func.__name__)))
+    if not settings.enable_debug_logger:
+        return
+    if not settings.enable_debug_internal_methods_logger and str(func.__name__)[0] == "_":
+        return
+    if not settings.enable_debug_geometry_operator_logger and "GeometryOperators" in str(func):
+        return
+    if (
+        not settings.enable_debug_edb_logger
+        and "Edb" in str(func) + str(new_args)
+        or "edb_core" in str(func) + str(new_args)
+    ):
+        return
+    line_begin = "    Implicit Arguments: "
+    line_begin2 = "    Explicit Arguments: "
+    message = []
+    if new_args:
+        object_name = str([new_args[0]])[1:-1]
+        id = object_name.find(" object at ")
+        if id >= 0:
+            object_name = object_name[1:id]
+            message.append(" '{}' has been exectuted.".format(object_name + "." + str(func.__name__)))
+            if new_args[1:]:
+                message.append(line_begin + str(new_args[1:])[1:-1])
             if new_kwargs:
                 message.append(line_begin2 + str(new_kwargs)[1:-1])
-        for m in message:
-            logger.debug(m)
+
+        else:
+            message.append(" '{}' has been exectuted.".format(str(func.__name__)))
+            if new_args[1:]:
+                message.append(line_begin + str(new_args[1:])[1:-1])
+            if new_kwargs:
+                message.append(line_begin2 + str(new_kwargs)[1:-1])
+
+    else:
+        message.append(" '{}' has been exectuted".format(str(func.__name__)))
+        if new_kwargs:
+            message.append(line_begin2 + str(new_kwargs)[1:-1])
+    for m in message:
+        logger.debug(m)
 
 
 def aedt_exception_handler(func):
@@ -216,7 +239,7 @@ def aedt_exception_handler(func):
 
     @wraps(func)
     def inner_function(*args, **kwargs):
-        if os.getenv("PYAEDT_ERROR_HANDLER", "True").lower() in ("true", "1", "t"):
+        if settings.enable_error_handler:
             try:
                 new_args = _remote_list_conversion(args)
                 new_kwargs = _remote_dict_conversion(kwargs)
@@ -251,12 +274,12 @@ def aedt_exception_handler(func):
                 return False
             except MethodNotSupportedError:
                 message = "This Method is not supported in current AEDT Design Type."
-                if os.getenv("PYAEDT_SCREEN_LOGS", "True").lower() in ("true", "1", "t"):
+                if settings.enable_screen_logs:
                     print("**************************************************************")
                     print("pyaedt error on Method {}:  {}. Please Check again".format(func.__name__, message))
                     print("**************************************************************")
                     print("")
-                if os.getenv("PYAEDT_FILE_LOGS", "True").lower() in ("true", "1", "t"):
+                if settings.enable_file_logs:
                     logger.error(message)
                 return False
             except BaseException:
@@ -531,3 +554,204 @@ def write_csv(output, list_data, delimiter=",", quotechar="|", quoting=csv.QUOTE
         writer.writerow(data)
     f.close()
     return True
+
+
+@aedt_exception_handler
+def filter_tuple(value, search_key1, search_key2):
+    """Filter a tuple of 2 elements with two search keywords"""
+    ignore_case = True
+
+    def _create_pattern(k1, k2):
+        k1a = re.sub(r"\?", r".", k1)
+        k1b = re.sub(r"\*", r".*?", k1a)
+        k2a = re.sub(r"\?", r".", k2)
+        k2b = re.sub(r"\*", r".*?", k2a)
+        pattern = r".*\({},{}\)".format(k1b, k2b)
+        return pattern
+
+    if ignore_case:
+        compiled_re = re.compile(_create_pattern(search_key1, search_key2), re.IGNORECASE)
+    else:
+        compiled_re = re.compile(_create_pattern(search_key1, search_key2))
+
+    m = compiled_re.search(value)
+    if m:
+        return True
+    return False
+
+
+@aedt_exception_handler
+def filter_string(value, search_key1):
+    """Filter a string"""
+    ignore_case = True
+
+    def _create_pattern(k1):
+        k1a = re.sub(r"\?", r".", k1.replace("\\", "\\\\"))
+        k1b = re.sub(r"\*", r".*?", k1a)
+        pattern = r"^{}$".format(k1b)
+        return pattern
+
+    if ignore_case:
+        compiled_re = re.compile(_create_pattern(search_key1), re.IGNORECASE)
+    else:
+        compiled_re = re.compile(_create_pattern(search_key1))  # pragma: no cover
+
+    m = compiled_re.search(value)
+    if m:
+        return True
+    return False
+
+
+@aedt_exception_handler
+def recursive_glob(startpath, filepattern):
+    """Return a list of files matching a pattern, searching recursively from a start path.
+
+    Keyword Arguments:
+    startpath -- starting path (directory)
+    filepattern -- fnmatch-style filename pattern
+    """
+    return [
+        os.path.join(dirpath, filename)
+        for dirpath, _, filenames in os.walk(startpath)
+        for filename in filenames
+        if fnmatch.fnmatch(filename, filepattern)
+    ]
+
+
+class Settings(object):
+    """Class that manages all PyAEDT Environment Variables and global settings."""
+
+    def __init__(self):
+        self._enable_logger = True
+        self._enable_desktop_logs = True
+        self._enable_screen_logs = True
+        self._enable_file_logs = True
+        self.pyaedt_server_path = ""
+        self._logger_file_path = None
+        self._logger_formatter = "%(asctime)s:%(destination)s:%(extra)s%(levelname)-8s:%(message)s"
+        self._logger_datefmt = "%Y/%m/%d %H.%M.%S"
+        self._enable_debug_edb_logger = False
+        self._enable_debug_geometry_operator_logger = False
+        self._enable_debug_internal_methods_logger = False
+        self._enable_debug_logger = False
+        self._enable_error_handler = True
+
+    @property
+    def enable_error_handler(self):
+        """Return the Environment Variable Content."""
+        return self._enable_error_handler
+
+    @enable_error_handler.setter
+    def enable_error_handler(self, val):
+        self._enable_error_handler = val
+
+    @property
+    def enable_desktop_logs(self):
+        """Return the Environment Variable Content."""
+        return self._enable_desktop_logs
+
+    @enable_desktop_logs.setter
+    def enable_desktop_logs(self, val):
+        self._enable_desktop_logs = val
+
+    @property
+    def enable_screen_logs(self):
+        """Return the Environment Variable Content."""
+        return self._enable_screen_logs
+
+    @enable_screen_logs.setter
+    def enable_screen_logs(self, val):
+        self._enable_screen_logs = val
+
+    @property
+    def pyaedt_server_path(self):
+        """Return the Environment Variable Content."""
+        return os.getenv("PYAEDT_SERVER_AEDT_PATH", "")
+
+    @pyaedt_server_path.setter
+    def pyaedt_server_path(self, val):
+        os.environ["PYAEDT_SERVER_AEDT_PATH"] = str(val)
+
+    @property
+    def enable_file_logs(self):
+        """Return the Environment Variable Content."""
+        return self._enable_file_logs
+
+    @enable_file_logs.setter
+    def enable_file_logs(self, val):
+        self._enable_file_logs = val
+
+    @property
+    def enable_logger(self):
+        """Return the Environment Variable Content."""
+        return self._enable_logger
+
+    @enable_logger.setter
+    def enable_logger(self, val):
+        self._enable_logger = val
+
+    @property
+    def logger_file_path(self):
+        """Return the Environment Variable Content."""
+        return self._logger_file_path
+
+    @logger_file_path.setter
+    def logger_file_path(self, val):
+        self._logger_file_path = val
+
+    @property
+    def logger_formatter(self):
+        """Return the Environment Variable Content."""
+        return self._logger_formatter
+
+    @logger_formatter.setter
+    def logger_formatter(self, val):
+        self._logger_formatter = val
+
+    @property
+    def logger_datefmt(self):
+        """Return the Environment Variable Content."""
+        return self._logger_datefmt
+
+    @logger_datefmt.setter
+    def logger_datefmt(self, val):
+        self._logger_datefmt = val
+
+    @property
+    def enable_debug_edb_logger(self):
+        """Return the Environment Variable Content."""
+        return self._enable_debug_edb_logger
+
+    @enable_debug_edb_logger.setter
+    def enable_debug_edb_logger(self, val):
+        self._enable_debug_edb_logger = val
+
+    @property
+    def enable_debug_geometry_operator_logger(self):
+        """Return the Environment Variable Content."""
+        return self._enable_debug_geometry_operator_logger
+
+    @enable_debug_geometry_operator_logger.setter
+    def enable_debug_geometry_operator_logger(self, val):
+        self._enable_debug_geometry_operator_logger = val
+
+    @property
+    def enable_debug_internal_methods_logger(self):
+        """Return the Environment Variable Content."""
+        return self._enable_debug_internal_methods_logger
+
+    @enable_debug_internal_methods_logger.setter
+    def enable_debug_internal_methods_logger(self, val):
+        self._enable_debug_internal_methods_logger = val
+
+    @property
+    def enable_debug_logger(self):
+        """Return the Environment Variable Content."""
+        return self._enable_debug_logger
+
+    @enable_debug_logger.setter
+    def enable_debug_logger(self, val):
+        self._enable_debug_logger = val
+
+
+settings = Settings()
