@@ -1,14 +1,11 @@
 import os
 import os.path
-import warnings
 
-from .general_methods import env_path
+from pyaedt.generic.general_methods import env_path
+from pyaedt import is_ironpython
 
-if os.name == "posix":
-    try:
-        import subprocessdotnet as subprocess
-    except:
-        warnings.warn("Pythonnet is needed to run pyaedt within Linux")
+if os.name == "posix" and is_ironpython:
+    import subprocessdotnet as subprocess
 else:
     import subprocess
 
@@ -29,7 +26,7 @@ class AedtSolve(object):
     >>> solver.solve()
     """
 
-    def __init__(self, aedt_version="2021.1", aedt_installer_path=None):
+    def __init__(self, aedt_version="2021.2", aedt_installer_path=None):
         self._project_path = ""
         self._command = []
         self._nbcores = 4
@@ -126,7 +123,7 @@ class AedtSolve(object):
 
 
 class SiwaveSolve(object):
-    def __init__(self, project_path, aedt_version="2021.1", aedt_installer_path=None):
+    def __init__(self, project_path, aedt_version="2021.2", aedt_installer_path=None):
         self._project_path = project_path
         self._exec_path = ""
         self._nbcores = 4
@@ -215,7 +212,7 @@ class SiwaveSolve(object):
             p = subprocess.Popen(" ".join(command))
             p.wait()
 
-    def export_3d_cad(self, format_3d="Q3D", output_folder=None, net_list=None, num_cores=None):
+    def export_3d_cad(self, format_3d="Q3D", output_folder=None, net_list=None, num_cores=None, aedt_file_name=None):
         """Export edb to Q3D or HFSS
 
         Parameters
@@ -227,7 +224,8 @@ class SiwaveSolve(object):
             Define Nets to Export. if None, all nets will be exported
         num_cores : int, optional
             Define number of cores to use during export
-
+        aedt_file_name : str, optional
+            Output  aedt file name (without .aedt extension). If `` then default naming is used
         Returns
         -------
         str
@@ -250,7 +248,9 @@ class SiwaveSolve(object):
                 f.write("    if allnets[i] != 'DUMMY':\n")
                 f.write("        oDoc.ScrSelectNet(allnets[i], 1)\n")
             f.write("oDoc.ScrSetOptionsFor3DModelExport(exportOptions)\n")
-            f.write("q3d_filename = os.path.join(r'{}', '{}')\n".format(output_folder, format_3d + "_siwave.aedt"))
+            if not aedt_file_name:
+                aedt_file_name = format_3d + "_siwave.aedt"
+            f.write("q3d_filename = os.path.join(r'{}', '{}')\n".format(output_folder, aedt_file_name))
             if num_cores:
                 f.write("oDoc.ScrSetNumCpusToUse('{}')\n".format(num_cores))
                 self.nbcores = num_cores
@@ -266,5 +266,6 @@ class SiwaveSolve(object):
         command.append(scriptname)
         print(command)
         os.system(" ".join(command))
-
-        return os.path.join(output_folder, format_3d + "_siwave.aedt")
+        # p1 = subprocess.call(" ".join(command))
+        # p1.wait()
+        return os.path.join(output_folder, aedt_file_name)
