@@ -2,8 +2,9 @@
 import math
 import re
 import sys
-from ..generic.general_methods import aedt_exception_handler
-from .modeler_constants import CoordinateSystemPlane, CoordinateSystemAxis, SweepDraftType
+from pyaedt.generic.general_methods import aedt_exception_handler
+from pyaedt.generic.constants import PLANE, AXIS, SWEEPDRAFT
+
 
 class GeometryOperators(object):
     """Manages geometry operators."""
@@ -136,7 +137,7 @@ class GeometryOperators(object):
 
     @staticmethod
     @aedt_exception_handler
-    def cs_plane_str(val):
+    def cs_plane_to_axis_str(val):
         """Retrieve a string for a coordinate system plane.
 
         Parameters
@@ -150,13 +151,36 @@ class GeometryOperators(object):
            String for the coordinate system plane.
 
         """
-        if val == CoordinateSystemPlane.XYPlane:
+        if val == PLANE.XY or val == "XY":
             return "Z"
-        elif val == CoordinateSystemPlane.YZPlane:
+        elif val == PLANE.YZ or val == "YZ":
             return "X"
         else:
             return "Y"
 
+    @staticmethod
+    @aedt_exception_handler
+    def cs_plane_to_plane_str(val):
+        """Retrieve a string for a coordinate system plane.
+
+        Parameters
+        ----------
+        val :
+
+
+        Returns
+        -------
+        str
+           String for the coordinate system plane.
+
+        """
+        if val == PLANE.XY or val == "XY":
+            return "XY"
+        elif val == PLANE.YZ or val == "YZ":
+            return "YZ"
+        else:
+            return "ZX"
+
     @staticmethod
     @aedt_exception_handler
     def cs_axis_str(val):
@@ -173,9 +197,9 @@ class GeometryOperators(object):
             String for the coordinate system axis.
 
         """
-        if val == CoordinateSystemAxis.XAxis or val == "X":
+        if val == AXIS.X or val == "X":
             return "X"
-        elif val == CoordinateSystemAxis.YAxis or val == "Y":
+        elif val == AXIS.Y or val == "Y":
             return "Y"
         else:
             return "Z"
@@ -196,9 +220,9 @@ class GeometryOperators(object):
            Type of the draft.
 
         """
-        if val == SweepDraftType.ExtendedDraft:
+        if val == SWEEPDRAFT.Extended:
             return "Extended"
-        elif val == SweepDraftType.RoundDraft:
+        elif val == SWEEPDRAFT.Round:
             return "Round"
         else:
             return "Natural"
@@ -613,6 +637,34 @@ class GeometryOperators(object):
         var = GeometryOperators._v_dot(va, vb) / (an * bn)
         return abs(var)
 
+    @staticmethod
+    @aedt_exception_handler
+    def is_collinear(a, b, tol=1e-6):
+        """Check if two vectors are collinear (parallel or anti-parallel).
+
+        Parameters
+        ----------
+        a : list
+            List of ``[x, y, z]`` coordinates for the first vector.
+        b : list
+            List of ``[x, y, z]`` coordinates for the second vector.
+        tol : float
+            Linear tolerance. The default value is ``1e-6``.
+
+        Returns
+        -------
+        bool
+            ``True`` if vectors are collinear, ``False`` otherwise.
+
+        """
+        an = GeometryOperators.v_norm(a)
+        bn = GeometryOperators.v_norm(b)
+        var = GeometryOperators._v_dot(a, b) / (an * bn)
+        if 1.0 - abs(var) < tol * tol:
+            return True
+        else:
+            return False
+
     @staticmethod
     @aedt_exception_handler
     def is_projection_inside(a1, a2, b1, b2):
@@ -1216,7 +1268,10 @@ class GeometryOperators(object):
             List of [x,y,z] coordinates for the centroid of the polygon.
 
         """
+        if len(pts) == 0:
+            raise AttributeError("pts must contain at list one point")
         sx = sy = sz = sl = sl2 = 0
+        x1, y1, z1 = pts[0]
         for i in range(len(pts)):  # counts from 0 to len(points)-1
             x0, y0, z0 = pts[i - 1]  # in Python points[-1] is last element of points
             x1, y1, z1 = pts[i]
@@ -1227,9 +1282,9 @@ class GeometryOperators(object):
             sz += (z0 + z1) / 2 * L2
             sl += L
             sl2 += L2
-        xc = sx / sl
-        yc = sy / sl
-        zc = sz / sl2
+        xc = sx / sl if sl != 0.0 else x1
+        yc = sy / sl if sl != 0.0 else y1
+        zc = sz / sl2 if sl2 != 0.0 else z1
 
         return [xc, yc, zc]
 
@@ -1324,3 +1379,72 @@ class GeometryOperators(object):
                 return [GeometryOperators.get_numeric(s) if type(s) is str else s for s in cs_in]
             else:
                 return [0, 0, 0]
+
+    @staticmethod
+    @aedt_exception_handler
+    def orient_polygon(x, y, clockwise=True):
+        """
+        Orient a polygon clockwise or counterclockwise.
+        The polygon is represented by its vertices coordinates.
+
+        Parameters
+        ----------
+        x : list
+            List of x coordinates of the vertices. Length must be >= 3.
+        y : list
+            List of y coordinates of the vertices. Must be of the same length as x.
+        clockwise : bool
+            If `True` the polygon is oriented colckwise, if `False` it is oriented counterclockwise.
+            Default is `True`.
+
+        Returns
+        -------
+        list, list
+            Lists of oriented vertices
+        """
+        # select a vertex on the hull
+        if len(x) < 3:
+            raise AttributeError("x length must be >= 3")
+        if len(y) != len(x):
+            raise AttributeError("y must be same length as x.")
+        # fmt: off
+        xmin = min(x)
+        ixmin = [i for i, el in enumerate(x) if xmin == el]
+        if len(ixmin) == 1:
+            imin = ixmin[0]
+        else:  # searching for the minimum y
+            tmpy = [(i, el) for i, el in enumerate(y) if i in ixmin]
+            min_tmpy = min(tmpy, key=lambda t: t[1])
+            imin = min_tmpy[0]
+        ymin = y[imin]
+        if imin == 0:  # the minimum is the first point of the polygon
+            xa = x[-1]
+            ya = y[-1]
+            xb = xmin
+            yb = ymin
+            xc = x[1]
+            yc = y[1]
+        elif imin == len(x)-1:  # the minimum is the last point of the polygon
+            xa = x[imin-1]
+            ya = y[imin-1]
+            xb = xmin
+            yb = ymin
+            xc = x[0]
+            yc = y[0]
+        else:
+            xa = x[imin-1]
+            ya = y[imin-1]
+            xb = xmin
+            yb = ymin
+            xc = x[imin+1]
+            yc = y[imin+1]
+        det = (xb-xa) * (yc-ya) - (xc-xa) * (yb-ya)
+        if det > 0:  # counterclockwise
+            is_CW = False
+        else:   # clockwise
+            is_CW = True
+        # fmt: on
+        if (clockwise and not is_CW) or (not clockwise and is_CW):
+            x.reverse()
+            y.reverse()
+        return x, y
