@@ -1,5 +1,7 @@
 import os
 from math import pi, cos, sin, tan
+import random
+import string
 
 from pyaedt.generic.general_methods import aedt_exception_handler
 from pyaedt.modeler.Primitives import Primitives
@@ -14,7 +16,7 @@ class Primitives3D(Primitives, object):
 
     This class is inherited in the caller application and is
     accessible through the primitives variable part of modeler object(
-    e.g. ``hfss.modeler.primitives`` or ``icepak.modeler.primitives``).
+    e.g. ``hfss.modeler`` or ``icepak.modeler``).
 
     Parameters
     ----------
@@ -27,7 +29,7 @@ class Primitives3D(Primitives, object):
 
     >>> from pyaedt import Hfss
     >>> aedtapp = Hfss()
-    >>> prim = aedtapp.modeler.primitives
+    >>> prim = aedtapp.modeler
     """
 
     def __init__(self):
@@ -45,6 +47,56 @@ class Primitives3D(Primitives, object):
 
         """
 
+    @aedt_exception_handler
+    def create_point(self, position, name=None, color="(143 175 143)"):
+        """Create a point.
+
+        Parameters
+        ----------
+        position : list
+            List of ``[x, y, z]`` coordinates. Note, The list can be empty or contain less than 3 elements.
+        name : str, optional
+            Name of the point. The default is ``None``, in which case the
+            default name is assigned.
+        color : str, optional
+            String exposing 3 int values such as "(value1 value2 value3)". Default value is ``"(143 175 143)"``.
+
+        Returns
+        -------
+        :class:`pyaedt.modeler.Object3d.Point`
+            Point object.
+
+        References
+        ----------
+
+        >>> oEditor.CreateBox
+
+        Examples
+        --------
+
+        >>> from pyaedt import hfss
+        >>> hfss = Hfss()
+        >>> point_object = hfss.modeler.primivites.create_point([0,0,0], name="mypoint")
+
+        """
+        x_position, y_position, z_position = self._pos_with_arg(position)
+
+        if not name:
+            unique_name = "".join(random.sample(string.ascii_uppercase + string.digits, 6))
+            name = "NewPoint_" + unique_name
+
+        parameters = ["NAME:PointParameters"]
+        parameters.append("PointX:="), parameters.append(x_position)
+        parameters.append("PointY:="), parameters.append(y_position)
+        parameters.append("PointZ:="), parameters.append(z_position)
+
+        attributes = ["NAME:Attributes"]
+        attributes.append("Name:="), attributes.append(name)
+        attributes.append("Color:="), attributes.append(color)
+
+        point = _retry_ntimes(10, self._oeditor.CreatePoint, parameters, attributes)
+        return self._create_point(name)
+
     @aedt_exception_handler
     def create_box(self, position, dimensions_list, name=None, matname=None):
         """Create a box.
@@ -138,9 +190,9 @@ class Primitives3D(Primitives, object):
         --------
         >>> from pyaedt import Hfss
         >>> aedtapp = Hfss()
-        >>> cylinder_object = aedtapp.modeler.primitives.create_cylinder(cs_axis='Z', position=[0,0,0],
-        ...                                                              radius=2, height=3, name="mycyl",
-        ...                                                              matname="vacuum")
+        >>> cylinder_object = aedtapp.modeler..create_cylinder(cs_axis='Z', position=[0,0,0],
+        ...                                                   radius=2, height=3, name="mycyl",
+        ...                                                   matname="vacuum")
 
         """
         if isinstance(radius, (int, float)) and radius < 0:
@@ -213,9 +265,9 @@ class Primitives3D(Primitives, object):
         --------
         >>> from pyaedt import Hfss
         >>> aedtapp = Hfss()
-        >>> ret_obj = aedtapp.modeler.primitives.create_polyhedron(cs_axis='X', center_position=[0, 0, 0],
-        ...                                                        start_position=[0,5,0], height=0.5,
-        ...                                                        num_sides=8, name="mybox", matname="copper")
+        >>> ret_obj = aedtapp.modeler.create_polyhedron(cs_axis='X', center_position=[0, 0, 0],
+        ...                                             start_position=[0,5,0], height=0.5,
+        ...                                              num_sides=8, name="mybox", matname="copper")
 
         """
         test = cs_axis
@@ -278,9 +330,9 @@ class Primitives3D(Primitives, object):
         --------
         >>> from pyaedt import Hfss
         >>> aedtapp = Hfss()
-        >>> cone_object = aedtapp.modeler.primitives.create_cone(cs_axis='Z', position=[0, 0, 0],
-        ...                                                      bottom_radius=2, top_radius=3, height=4,
-        ...                                                      name="mybox", matname="copper")
+        >>> cone_object = aedtapp.modeler.create_cone(cs_axis='Z', position=[0, 0, 0],
+        ...                                           bottom_radius=2, top_radius=3, height=4,
+        ...                                           name="mybox", matname="copper")
 
         """
         if bottom_radius == top_radius:
@@ -342,8 +394,8 @@ class Primitives3D(Primitives, object):
         --------
         >>> from pyaedt import Hfss
         >>> aedtapp = Hfss()
-        >>> ret_object = aedtapp.modeler.primitives.create_sphere(position=[0,0,0], radius=2,
-        ...                                                      name="mysphere", matname="copper")
+        >>> ret_object = aedtapp.modeler.create_sphere(position=[0,0,0], radius=2,
+        ...                                            name="mysphere", matname="copper")
 
         """
         if len(position) != 3:
@@ -404,9 +456,9 @@ class Primitives3D(Primitives, object):
         >>> from pyaedt import Hfss
         >>> hfss = Hfss()
         >>> origin = [0, 0, 0]
-        >>> torus = hfss.modeler.primitives.create_torus(origin, major_radius=1,
-        ...                                              minor_radius=0.5, axis="Z",
-        ...                                              name="mytorus", material_name="copper")
+        >>> torus = hfss.modeler.create_torus(origin, major_radius=1,
+        ...                                   minor_radius=0.5, axis="Z",
+        ...                                    name="mytorus", material_name="copper")
 
         """
         if len(center) != 3:
@@ -1418,7 +1470,7 @@ class Primitives3D(Primitives, object):
         >>> from pyaedt import Hfss
         >>> app = Hfss()
         >>> bird_dir = "path/to/bird/directory"
-        >>> bird1 = app.modeler.primitives.add_bird(bird_dir, 1.0, [19, 4, 3], 120, -5, flapping_rate=30)
+        >>> bird1 = app.modeler.add_bird(bird_dir, 1.0, [19, 4, 3], 120, -5, flapping_rate=30)
 
         """
         self._initialize_multipart()
