@@ -2,11 +2,13 @@
 This module contains these classes: `BoundaryCommon` and `BoundaryObject`.
 """
 from collections import OrderedDict
-from pyaedt.generic.general_methods import aedt_exception_handler
+
+from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name, filter_tuple
 from pyaedt.generic.DataHandlers import _dict2arg
 from pyaedt.modeler.Object3d import EdgePrimitive, FacePrimitive, VertexPrimitive
 from pyaedt.generic.DataHandlers import random_string
 from pyaedt.modeler.Object3d import _dim_arg
+from pyaedt.generic.constants import CATEGORIESQ3D
 
 
 class BoundaryCommon(object):
@@ -159,12 +161,12 @@ class NativeComponentObject(BoundaryCommon, object):
         """
         self.name = "InsertNativeComponentData"
         try:
-            names = [i for i in self._app.modeler.get_excitations_name()]
+            names = [i for i in self._app.excitations]
         except Exception as e:
             names = []
         self.antennaname = self._app.modeler.oeditor.InsertNativeComponent(self._get_args())
         try:
-            a = [i for i in self._app.modeler.get_excitations_name() if i not in names]
+            a = [i for i in self._app.excitations if i not in names]
             self.excitation_name = a[0].split(":")[0]
         except Exception as e:
             self.excitation_name = self.antennaname
@@ -232,8 +234,8 @@ class BoundaryObject(BoundaryCommon, object):
     >>> from pyaedt import Hfss
     >>> hfss =Hfss()
     >>> origin = hfss.modeler.Position(0, 0, 0)
-    >>> inner = hfss.modeler.primitives.create_cylinder(hfss.PLANE.XY, origin, 3, 200, 0, "inner")
-    >>> inner_id = hfss.modeler.primitives.get_obj_id("inner")
+    >>> inner = hfss.modeler.create_cylinder(hfss.PLANE.XY, origin, 3, 200, 0, "inner")
+    >>> inner_id = hfss.modeler.get_obj_id("inner")
     >>> coat = hfss.assign_coating([inner_id], "copper", usethickness=True, thickness="0.2mm")
     """
 
@@ -242,6 +244,7 @@ class BoundaryObject(BoundaryCommon, object):
         self.name = name
         self.props = props
         self.type = boundarytype
+        self._boundary_name = self.name
 
     @aedt_exception_handler
     def _get_args(self, props=None):
@@ -376,6 +379,16 @@ class BoundaryObject(BoundaryCommon, object):
             self._app.oboundary.AssignSource(self._get_args())
         elif self.type == "Sink":
             self._app.oboundary.AssignSink(self._get_args())
+        elif self.type == "SignalNet":
+            self._app.oboundary.AssignSignalNet(self._get_args())
+        elif self.type == "GroundNet":
+            self._app.oboundary.AssignGroundNet(self._get_args())
+        elif self.type == "FloatingNet":
+            self._app.oboundary.AssignFloatingNet(self._get_args())
+        elif self.type == "SignalLine":
+            self._app.oboundary.AssignSingleSignalLine(self._get_args())
+        elif self.type == "ReferenceGround":
+            self._app.oboundary.AssignSingleReferenceGround(self._get_args())
         elif self.type == "CircuitPort":
             self._app.oboundary.AssignCircuitPort(self._get_args())
         elif self.type == "LumpedPort":
@@ -409,105 +422,112 @@ class BoundaryObject(BoundaryCommon, object):
 
         """
         if self.type == "PerfectE":
-            self._app.oboundary.EditPerfectE(self.name, self._get_args())
+            self._app.oboundary.EditPerfectE(self._boundary_name, self._get_args())
         elif self.type == "PerfectH":
-            self._app.oboundary.EditPerfectH(self.name, self._get_args())
+            self._app.oboundary.EditPerfectH(self._boundary_name, self._get_args())
         elif self.type == "Aperture":
-            self._app.oboundary.EditAperture(self.name, self._get_args())
+            self._app.oboundary.EditAperture(self._boundary_name, self._get_args())
         elif self.type == "Radiation":
-            self._app.oboundary.EditRadiation(self.name, self._get_args())
+            self._app.oboundary.EditRadiation(self._boundary_name, self._get_args())
         elif self.type == "FiniteCond":
-            self._app.oboundary.EditFiniteCond(self.name, self._get_args())
+            self._app.oboundary.EditFiniteCond(self._boundary_name, self._get_args())
         elif self.type == "LumpedRLC":
-            self._app.oboundary.EditLumpedRLC(self.name, self._get_args())
+            self._app.oboundary.EditLumpedRLC(self._boundary_name, self._get_args())
         elif self.type == "Impedance":
-            self._app.oboundary.EditImpedance(self.name, self._get_args())
+            self._app.oboundary.EditImpedance(self._boundary_name, self._get_args())
         elif self.type == "Anisotropic Impedance":
-            self._app.oboundary.EditAssignAnisotropicImpedance(self.name, self._get_args())
+            self._app.oboundary.EditAssignAnisotropicImpedance(
+                self._boundary_name, self._get_args()
+            )  # pragma: no cover
         elif self.type == "Primary":
-            self._app.oboundary.EditPrimary(self.name, self._get_args())
+            self._app.oboundary.EditPrimary(self._boundary_name, self._get_args())
         elif self.type == "Secondary":
-            self._app.oboundary.EditSecondary(self.name, self._get_args())
+            self._app.oboundary.EditSecondary(self._boundary_name, self._get_args())
         elif self.type == "Lattice Pair":
-            self._app.oboundary.EditLatticePair(self.name, self._get_args())
+            self._app.oboundary.EditLatticePair(self._boundary_name, self._get_args())
         elif self.type == "HalfSpace":
-            self._app.oboundary.EditHalfSpace(self.name, self._get_args())
+            self._app.oboundary.EditHalfSpace(self._boundary_name, self._get_args())
         elif self.type == "Multipaction SEE":
-            self._app.oboundary.EditMultipactionSEE(self.name, self._get_args())
+            self._app.oboundary.EditMultipactionSEE(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "Fresnel":
-            self._app.oboundary.EditFresnel(self.name, self._get_args())
+            self._app.oboundary.EditFresnel(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "Symmetry":
-            self._app.oboundary.EditSymmetry(self.name, self._get_args())
+            self._app.oboundary.EditSymmetry(self._boundary_name, self._get_args())
         elif self.type == "Zero Tangential H Field":
-            self._app.oboundary.EditZeroTangentialHField(self.name, self._get_args())
+            self._app.oboundary.EditZeroTangentialHField(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "Zero Integrated Tangential H Field":
-            self._app.oboundary.EditIntegratedZeroTangentialHField(self.name, self._get_args())
+            self._app.oboundary.EditIntegratedZeroTangentialHField(
+                self._boundary_name, self._get_args()
+            )  # pragma: no cover
         elif self.type == "Tangential H Field":
-            self._app.oboundary.EditTangentialHField(self.name, self._get_args())
+            self._app.oboundary.EditTangentialHField(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "Insulating":
-            self._app.oboundary.EditInsulating(self.name, self._get_args())
+            self._app.oboundary.EditInsulating(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "Independent":
-            self._app.oboundary.EditIndependent(self.name, self._get_args())
+            self._app.oboundary.EditIndependent(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "Dependent":
-            self._app.oboundary.EditDependent(self.name, self._get_args())
+            self._app.oboundary.EditDependent(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "Band":
-            self._app.omodelsetup.EditMotionSetup(self.name, self._get_args())
+            self._app.omodelsetup.EditMotionSetup(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "InfiniteGround":
-            self._app.oboundary.EditInfiniteGround(self.name, self._get_args())
+            self._app.oboundary.EditInfiniteGround(self._boundary_name, self._get_args())
         elif self.type == "ThinConductor":
-            self._app.oboundary.EditThinConductor(self.name, self._get_args())
+            self._app.oboundary.EditThinConductor(self._boundary_name, self._get_args())
         elif self.type == "Stationary Wall":
-            self._app.oboundary.EditStationaryWallBoundary(self.name, self._get_args())
+            self._app.oboundary.EditStationaryWallBoundary(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "Symmetry Wall":
-            self._app.oboundary.EditSymmetryWallBoundary(self.name, self._get_args())
+            self._app.oboundary.EditSymmetryWallBoundary(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "Resistance":
-            self._app.oboundary.EditResistanceBoundary(self.name, self._get_args())
+            self._app.oboundary.EditResistanceBoundary(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "Conducting Plate":
-            self._app.oboundary.EditConductingPlateBoundary(self.name, self._get_args())
+            self._app.oboundary.EditConductingPlateBoundary(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "Adiabatic Plate":
-            self._app.oboundary.EditAdiabaticPlateBoundary(self.name, self._get_args())
+            self._app.oboundary.EditAdiabaticPlateBoundary(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "Network":
-            self._app.oboundary.EditNetworkBoundary(self.name, self._get_args())
+            self._app.oboundary.EditNetworkBoundary(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "Grille":
-            self._app.oboundary.EditGrilleBoundary(self.name, self._get_args())
+            self._app.oboundary.EditGrilleBoundary(self._boundary_name, self._get_args())
         elif self.type == "Opening":
-            self._app.oboundary.EditOpeningBoundary(self.name, self._get_args())
+            self._app.oboundary.EditOpeningBoundary(self._boundary_name, self._get_args())
         elif self.type == "EMLoss":
-            self._app.oboundary.EditEMLoss(self.name, self._get_args())
+            self._app.oboundary.EditEMLoss(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "Block":
-            self._app.oboundary.EditBlockBoundary(self.name, self._get_args())
+            self._app.oboundary.EditBlockBoundary(self._boundary_name, self._get_args())
         elif self.type == "SourceIcepak":
             self._app.oboundary.EditSourceBoundary(self._get_args())
         elif self.type == "Voltage":
-            self._app.oboundary.EditVoltage(self.name, self._get_args())
+            self._app.oboundary.EditVoltage(self._boundary_name, self._get_args())
         elif self.type == "VoltageDrop":
-            self._app.oboundary.EditVoltageDrop(self.name, self._get_args())
+            self._app.oboundary.EditVoltageDrop(self._boundary_name, self._get_args())
         elif self.type == "Current":
-            self._app.oboundary.Current(self.name, self._get_args())
+            self._app.oboundary.Current(self._boundary_name, self._get_args())
         elif self.type == "Winding" or self.type == "Winding Group":
-            self._app.oboundary.EditWindingGroup(self.name, self._get_args())
+            self._app.oboundary.EditWindingGroup(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "VectorPotential":
-            self._app.oboundary.EditVectorPotential(self.name, self._get_args())
+            self._app.oboundary.EditVectorPotential(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "CoilTerminal":
-            self._app.oboundary.EditCoilTerminal(self.name, self._get_args())
+            self._app.oboundary.EditCoilTerminal(self._boundary_name, self._get_args())
         elif self.type == "Coil":
-            self._app.oboundary.EditCoil(self.name, self._get_args())
+            self._app.oboundary.EditCoil(self._boundary_name, self._get_args())
         elif self.type == "Source":
-            self._app.oboundary.EditTerminal(self.name, self._get_args())
+            self._app.oboundary.EditTerminal(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "Sink":
-            self._app.oboundary.EditSink(self.name, self._get_args())
+            self._app.oboundary.EditTerminal(self._boundary_name, self._get_args())
+        elif self.type == "SignalNet" or self.type == "GroundNet" or self.type == "FloatingNet":
+            self._app.oboundary.EditTerminal(self._boundary_name, self._get_args())
         elif self.type in ["CircuitPort", "Circuit Port"]:
-            self._app.oboundary.EditCircuitPort(self.name, self._get_args())
+            self._app.oboundary.EditCircuitPort(self._boundary_name, self._get_args())
         elif self.type in ["LumpedPort", "Lumped Port"]:
-            self._app.oboundary.EditLumpedPort(self.name, self._get_args())
+            self._app.oboundary.EditLumpedPort(self._boundary_name, self._get_args())
         elif self.type in ["WavePort", "Wave Port"]:
-            self._app.oboundary.EditWavePort(self.name, self._get_args())
+            self._app.oboundary.EditWavePort(self._boundary_name, self._get_args())
         elif self.type == "SetSBRTxRxSettings":
-            self._app.oboundary.SetSBRTxRxSettings(self._get_args())
+            self._app.oboundary.SetSBRTxRxSettings(self._get_args())  # pragma: no cover
         elif self.type == "FloquetPort":
-            self._app.oboundary.EditFloquetPort(self.name, self._get_args())
+            self._app.oboundary.EditFloquetPort(self._boundary_name, self._get_args())  # pragma: no cover
         else:
-            return False
+            return False  # pragma: no cover
+        self._boundary_name = self.name
         return True
 
     @aedt_exception_handler
@@ -982,3 +1002,221 @@ class FarFieldSetup(FieldSetup, object):
         if "ElevationStep" in self.props:
             self.props["ElevationStep"] = _dim_arg(value, self.units)
             self.update()
+
+
+class Matrix(object):
+    """Manages Matrix in Q3d and Q2d Projects.
+
+    Examples
+    --------
+
+
+    """
+
+    def __init__(self, app, name, operations=None):
+        self._app = app
+        self.omatrix = self._app.omatrix
+        self.name = name
+        self._sources = []
+        if operations:
+            if isinstance(operations, list):
+                self._operations = operations
+            else:
+                self._operations = [operations]
+        self.CATEGORIES = CATEGORIESQ3D()
+
+    @aedt_exception_handler
+    def sources(self, is_gc_sources=True):
+        """List of matrix sources.
+
+        Parameters
+        ----------
+        is_gc_sources : bool,
+            In Q3d, define if to return GC sources or RL sources. Default `True`.
+
+        Returns
+        -------
+        List
+        """
+        if self.name in list(self._app.omatrix.ListReduceMatrixes()):
+            if self._app.design_type == "Q3D Extractor":
+                self._sources = list(self._app.omatrix.ListReduceMatrixReducedSources(self.name, is_gc_sources))
+            else:
+                self._sources = list(self._app.omatrix.ListReduceMatrixReducedSources(self.name))
+        return self._sources
+
+    @aedt_exception_handler
+    def get_sources_for_plot(
+        self,
+        get_self_terms=True,
+        get_mutual_terms=True,
+        first_element_filter=None,
+        second_element_filter=None,
+        category="C",
+    ):
+        """Return a list of source of specified matrix ready to be used in plot reports.
+
+        Parameters
+        ----------
+        get_self_terms : bool
+            Either if self terms have to be returned or not.
+        get_mutual_terms : bool
+            Either if mutual terms have to be returned or not.
+        first_element_filter : str, optional
+            Filter to apply to first element of equation. It accepts `*` and `?` as special characters.
+        second_element_filter : str, optional
+            Filter to apply to second element of equation. It accepts `*` and `?` as special characters.
+        category : str
+            Plot category name as in the report. Eg. "C" is category Capacitance.
+            Matrix `CATEGORIES` property can be used to map available categories.
+
+        Returns
+        -------
+        list
+
+        Examples
+        --------
+        >>> from pyaedt import Q3d
+        >>> q3d = Q3d(project_path)
+        >>> q3d.matrices[0].get_sources_for_plot(first_element_filter="Bo?1",
+        ...                                      second_element_filter="GND*", category="DCL")
+        """
+        if not first_element_filter:
+            first_element_filter = "*"
+        if not second_element_filter:
+            second_element_filter = "*"
+        is_cg = False
+        if category in [self.CATEGORIES.Q3D.C, self.CATEGORIES.Q3D.G]:
+            is_cg = True
+        list_output = []
+        if get_self_terms:
+            for el in self.sources(is_gc_sources=is_cg):
+                value = "{}({},{})".format(category, el, el)
+                if filter_tuple(value, first_element_filter, second_element_filter):
+                    list_output.append(value)
+        if get_mutual_terms:
+            for el1 in self.sources(is_gc_sources=is_cg):
+                for el2 in self.sources(is_gc_sources=is_cg):
+                    if el1 != el2:
+                        value = "{}({},{})".format(category, el1, el2)
+                        if filter_tuple(value, first_element_filter, second_element_filter):
+                            list_output.append(value)
+        return list_output
+
+    @property
+    def operations(self):
+        """List of matrix operations.
+
+        Returns
+        -------
+        List
+        """
+        if self.name in list(self._app.omatrix.ListReduceMatrixes()):
+            self._operations = self._app.omatrix.ListReduceMatrixOperations(self.name)
+        return self._operations
+
+    @aedt_exception_handler
+    def create(self, source_names=None):
+        """Create a new matrix.
+
+        Parameters
+        ----------
+        source_names : str, list
+            List or str containing the content of the matrix reduction (eg. source name).
+
+        Returns
+        -------
+        bool
+            `True` if succeeded.
+        """
+        if not isinstance(source_names, list) and source_names:
+            source_names = [source_names]
+        command = self._write_command(source_names)
+        self.omatrix.InsertRM(self.name, command)
+        return True
+
+    @aedt_exception_handler
+    def delete(self):
+        """Delete current matrix.
+
+        Returns
+        -------
+        bool
+            `True` if succeeded.
+        """
+        self.omatrix.DeleteRM(self.name)
+        for el in self._app.matrices:
+            if el.name == self.name:
+                self._app.matrices.remove(el)
+        return True
+
+    @aedt_exception_handler
+    def add_operation(self, operation_type, source_names=None):
+        """Add a new operation to existing matrix.
+
+        Parameters
+        ----------
+        operation_type : str
+            Operation to perform
+        source_names : str, list
+            List or str containing the content of the matrix reduction (eg. source name).
+
+        Returns
+        -------
+        bool
+            `True` if succeeded.
+        """
+        self._operations.append(operation_type)
+        if not isinstance(source_names, list) and source_names:
+            source_names = [source_names]
+        command = self._write_command(source_names)
+        self.omatrix.RMAddOp(self.name, command)
+        return True
+
+    @aedt_exception_handler
+    def _write_command(self, source_names):
+        command = ""
+        if self._operations[-1] == "JoinSeries":
+            new_name = generate_unique_name(source_names[0])
+            for el in self._app.boundaries:
+                if el.name == source_names[0]:
+                    new_name = el.props["Net"]
+            command = "{}('{}', '{}')".format(self._operations[-1], new_name, "', '".join(source_names))
+        elif self._operations[-1] == "JoinParallel":
+            new_name = generate_unique_name(source_names[0])
+            for el in self._app.boundaries:
+                if el.name == source_names[0]:
+                    new_name = el.props["Net"]
+            new_source = source_names[0]
+            new_sink = generate_unique_name("Sink")
+            command = "{}('{}', '{}', '{}', '{}')".format(
+                self._operations[-1], new_name, new_source, new_sink, "', '".join(source_names)
+            )
+        elif self._operations[-1] == "JoinSelectedTerminals":
+            command = "{}('', '{}')".format(self._operations[-1], "', '".join(source_names))
+        elif self._operations[-1] == "FloatInfinity":
+            command = "FloatInfinity()"
+        elif self._operations[-1] == "AddGround":
+            command = "{}(SelectionArray[{}: '{}'], OverrideInfo())".format(
+                self._operations[-1], len(source_names), "', '".join(source_names)
+            )
+        elif (
+            self._operations[-1] == "SetReferenceGround"
+            or self._operations[-1] == "SetReferenceGround"
+            or self._operations[-1] == "Float"
+        ):
+            command = "{}(SelectionArray[{}: '{}'], OverrideInfo())".format(
+                self._operations[-1], len(source_names), "', '".join(source_names)
+            )
+        elif self._operations[-1] == "Parallel" or self._operations[-1] == "DiffPair":
+            pair_name = generate_unique_name("Pair")
+            id = 0
+            for el in self._app.boundaries:
+                if el.name == source_names[0]:
+                    id = self._app.modeler[el.props["Objects"][0]].id
+            command = "{}(SelectionArray[{}: '{}'], OverrideInfo({}, '{}'))".format(
+                self._operations[-1], len(source_names), "', '".join(source_names), id, pair_name
+            )
+        else:
+            command = "{}('{}')".format(self._operations[-1], "', '".join(source_names))
+        return command
