@@ -762,7 +762,7 @@ class CommonMaterial(object):
         self.name = name
         self.coordinate_system = ""
         if props:
-            self._props = props
+            self._props = props.copy()
         else:
             self._props = OrderedDict()
         if "CoordinateSystemType" in self._props:
@@ -819,6 +819,9 @@ class CommonMaterial(object):
         ):
             i = 1
             for val in provpavlue:
+                if not self._props.get(propname, None) or isinstance(self._props[propname], str):
+                    self._props[propname] = OrderedDict({"property_type": "AnisoProperty"})
+                    self._props[propname]["unit"] = ""
                 self._props[propname]["component" + str(i)] = str(val)
                 i += 1
             if update_aedt:
@@ -891,7 +894,7 @@ class Material(CommonMaterial, object):
         else:
             self.physics_type = ["Electromagnetic", "Thermal", "Structural"]
             self._props["PhysicsTypes"] = OrderedDict({"set": ["Electromagnetic", "Thermal", "Structural"]})
-        if "AttachedData" in self._props:
+        if "AttachedData" in self._props and "MatAppearanceData" in self._props["AttachedData"]:
             self._material_appearance = []
             self._material_appearance.append(self._props["AttachedData"]["MatAppearanceData"]["Red"])
             self._material_appearance.append(self._props["AttachedData"]["MatAppearanceData"]["Green"])
@@ -1131,7 +1134,12 @@ class Material(CommonMaterial, object):
         self._thermal_conductivity.value = value
         self.physics_type = ["Electromagnetic", "Thermal", "Structural"]
         self._props["PhysicsTypes"] = OrderedDict({"set": ["Electromagnetic", "Thermal", "Structural"]})
-        self._update_props("thermal_conductivity", value)
+        if isinstance(value, list):
+            self._thermal_conductivity.type = "anisotropic"
+            self._update_props("thermal_conductivity", value)
+        else:
+            self._thermal_conductivity.type = "simple"
+            self._update_props("thermal_conductivity", value)
 
     @property
     def mass_density(self):
