@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """
 This module contains the `Materials` class.
 """
@@ -5,8 +6,10 @@ from __future__ import absolute_import
 
 import json
 import copy
-from ..generic.DataHandlers import arg2dict
-from pyaedt.generic.general_methods import aedt_exception_handler, retry_ntimes, generate_unique_name
+import os
+
+from pyaedt.generic.DataHandlers import _arg2dict
+from pyaedt.generic.general_methods import aedt_exception_handler, _retry_ntimes, generate_unique_name, is_ironpython
 from pyaedt.modules.Material import Material, SurfaceMaterial, MatProperties, OrderedDict
 
 
@@ -15,40 +18,25 @@ class Materials(object):
 
     Parameters
     ----------
-    parent : str
+    app : :class:`pyaedt.application.Analysis3D.FieldAnalysis3D`
         Inherited parent object.
 
+    Examples
+    --------
+    >>> from pyaedt import Hfss
+    >>> app = Hfss()
+    >>> materials = app.materials
     """
 
-    @property
-    def odefinition_manager(self):
-        """Definition manager."""
-        return self._parent._oproject.GetDefinitionManager()
-
-    @property
-    def omaterial_manager(self):
-        """Material manager."""
-        return self.odefinition_manager.GetManager("Material")
-
-    @property
-    def _messenger(self):
-        """Messenger.
-
-        Returns
-        -------
-        MessageManager
-            Message manager object.
-        """
-        return self._parent._messenger
-
-    @property
-    def oproject(self):
-        """Project."""
-        return self._parent.oproject
-
-    def __init__(self, parent):
-        self._parent = parent
-        self._messenger.logger.info("Successfully loaded project materials !")
+    def __init__(self, app):
+        self._app = app
+        self._color_id = 0
+        self.odefinition_manager = self._app.odefinition_manager
+        self.omaterial_manager = self._app.omaterial_manager
+        self._desktop = self._app.odesktop
+        self._oproject = self._app.oproject
+        self.logger = self._app.logger
+        self.logger.info("Successfully loaded project materials !")
         self.material_keys = self._get_materials()
         self.surface_material_keys = self._get_surface_materials()
         self._load_from_project()
@@ -67,14 +55,44 @@ class Materials(object):
         elif item in list(self.surface_material_keys.keys()):
             return self.surface_material_keys[item]
 
+    @property
+    def liquids(self):
+        """Return the liquids materials. A liquid is a fluid with density greater or equal to 100Kg/m3.
+
+        Returns
+        -------
+        list
+            List of fluid materials.
+        """
+        mats = []
+        for el, val in self.material_keys.items():
+            if val.thermal_material_type == "Fluid" and val.mass_density.value and float(val.mass_density.value) >= 100:
+                mats.append(el)
+        return mats
+
+    @property
+    def gases(self):
+        """Return the gas materials. A gas is a fluid with density lower than 100Kg/m3.
+
+        Returns
+        -------
+        list
+            List of all Gas materials.
+        """
+        mats = []
+        for el, val in self.material_keys.items():
+            if val.thermal_material_type == "Fluid" and val.mass_density.value and float(val.mass_density.value) < 100:
+                mats.append(el)
+        return mats
+
     @aedt_exception_handler
     def _get_materials(self):
         """Get materials."""
         mats = {}
         try:
-            for ds in self._parent.project_properies["AnsoftProject"]["Definitions"]["Materials"]:
+            for ds in self._app.project_properies["AnsoftProject"]["Definitions"]["Materials"]:
                 mats[ds.lower()] = Material(
-                    self, ds.lower(), self._parent.project_properies["AnsoftProject"]["Definitions"]["Materials"][ds]
+                    self, ds.lower(), self._app.project_properies["AnsoftProject"]["Definitions"]["Materials"][ds]
                 )
         except:
             pass
@@ -84,11 +102,11 @@ class Materials(object):
     def _get_surface_materials(self):
         mats = {}
         try:
-            for ds in self._parent.project_properies["AnsoftProject"]["Definitions"]["SurfaceMaterials"]:
+            for ds in self._app.project_properies["AnsoftProject"]["Definitions"]["SurfaceMaterials"]:
                 mats[ds.lower()] = SurfaceMaterial(
                     self,
                     ds.lower(),
-                    self._parent.project_properies["AnsoftProject"]["Definitions"]["SurfaceMaterials"][ds],
+                    self._app.project_properies["AnsoftProject"]["Definitions"]["SurfaceMaterials"][ds],
                 )
         except:
             pass
@@ -109,6 +127,11 @@ class Materials(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oDefinitionManager.GetProjectMaterialNames
+        >>> oMaterialManager.GetData
         """
         mat = mat.lower()
         lista = [i.lower() for i in list(self.odefinition_manager.GetProjectMaterialNames())]
@@ -170,6 +193,11 @@ class Materials(object):
         -------
         :class:`pyaedt.modules.Material.Material`
 
+        References
+        ----------
+
+        >>> oDefinitionManager.AddMaterial
+
         Examples
         --------
 
@@ -178,18 +206,19 @@ class Materials(object):
         >>> mat = hfss.materials.add_material("MyMaterial")
         >>> print(mat.conductivity.value)
 
+        >>> oDefinitionManager.GetProjectMaterialNames
+        >>> oMaterialManager.GetData
+
         """
         materialname = materialname.lower()
-        self._messenger.add_info_message("Adding new material to the Project Library: " + materialname)
+        self.logger.info("Adding new material to the Project Library: " + materialname)
         if materialname in self.material_keys:
-            self._messenger.add_warning_message(
-                "Warning. The material is already in the database. Change or edit the name."
-            )
+            self.logger.warning("Warning. The material is already in the database. Change or edit the name.")
             return self.material_keys[materialname]
         else:
-            material = Material(self._parent, materialname, props)
+            material = Material(self, materialname, props)
             material.update()
-            self._messenger.add_info_message("Material has been added. Edit it to update in Desktop.")
+            self.logger.info("Material has been added. Edit it to update in Desktop.")
             self.material_keys[materialname] = material
             return self.material_keys[materialname]
 
@@ -211,6 +240,11 @@ class Materials(object):
         -------
         :class:`pyaedt.modules.SurfaceMaterial`
 
+        References
+        ----------
+
+        >>> oDefinitionManager.AddSurfaceMaterial
+
         Examples
         --------
 
@@ -218,21 +252,20 @@ class Materials(object):
         >>> hfss = Hfss()
         >>> mat = hfss.materials.add_surface_material("Steel", 0.85)
         >>> print(mat.emissivity.value)
+
         """
 
         materialname = material_name.lower()
-        self._messenger.add_info_message("Adding a surface material to the project library: " + materialname)
+        self.logger.info("Adding a surface material to the project library: " + materialname)
         if materialname in self.surface_material_keys:
-            self._messenger.add_warning_message(
-                "Warning. The material is already in the database. Change the name or edit it."
-            )
+            self.logger.warning("Warning. The material is already in the database. Change the name or edit it.")
             return self.surface_material_keys[materialname]
         else:
-            material = SurfaceMaterial(self._parent, materialname)
+            material = SurfaceMaterial(self._app, materialname)
             if emissivity:
                 material.emissivity = emissivity
                 material.update()
-            self._messenger.add_info_message("Material has been added. Edit it to update in Desktop.")
+            self.logger.info("Material has been added. Edit it to update in Desktop.")
             self.surface_material_keys[materialname] = material
             return self.surface_material_keys[materialname]
 
@@ -246,7 +279,7 @@ class Materials(object):
                 try:
                     matprop[prop].append(float(mat.__dict__["_" + prop].value))
                 except:
-                    self._messenger.add_warning_message("Warning. Wrong parsed property. Reset to 0")
+                    self.logger.warning("Warning. Wrong parsed property. Reset to 0")
                     matprop[prop].append(0)
             try:
                 a = sum(matprop[prop])
@@ -279,6 +312,11 @@ class Materials(object):
         int
             Index of the project variable.
 
+        References
+        ----------
+
+        >>> oDefinitionManager.AddMaterial
+
         Examples
         --------
 
@@ -287,7 +325,6 @@ class Materials(object):
         >>> hfss.materials.add_material("MyMaterial")
         >>> hfss.materials.add_material("MyMaterial2")
         >>> hfss.materials.add_material_sweep(["MyMaterial", "MyMaterial2"], "Sweep_copper")
-
         """
         matsweep = []
         matname = matname.lower()
@@ -300,12 +337,12 @@ class Materials(object):
 
         mat_dict = self._create_mat_project_vars(matsweep)
 
-        newmat = Material(self._parent, matname)
+        newmat = Material(self, matname)
         index = "$ID" + matname
-        self._parent[index] = 0
+        self._app[index] = 0
         for el in mat_dict:
             if el in list(mat_dict.keys()):
-                self._parent["$" + matname + el] = mat_dict[el]
+                self._app["$" + matname + el] = mat_dict[el]
                 newmat.__dict__["_" + el].value = "$" + matname + el + "[" + index + "]"
                 newmat._update_props(el, "$" + matname + el + "[" + index + "]", False)
 
@@ -328,6 +365,11 @@ class Materials(object):
         -------
         :class:`pyaedt.modules.Material.Material`
 
+        References
+        ----------
+
+        >>> oDefinitionManager.AddMaterial
+
         Examples
         --------
 
@@ -338,7 +380,7 @@ class Materials(object):
 
         """
         if material.lower() not in list(self.material_keys.keys()):
-            self._messenger.add_error_message("Material {} is not present".format(material))
+            self.logger.error("Material {} is not present".format(material))
             return False
         newmat = Material(self, new_name.lower(), self.material_keys[material.lower()]._props)
         newmat.update()
@@ -360,6 +402,11 @@ class Materials(object):
         -------
         :class:`pyaedt.modules.SurfaceMaterial`
 
+        References
+        ----------
+
+        >>> oDefinitionManager.AddSurfaceMaterial
+
         Examples
         --------
 
@@ -367,10 +414,9 @@ class Materials(object):
         >>> hfss = Hfss()
         >>> hfss.materials.add_surface_material("MyMaterial")
         >>> hfss.materials.duplicate_surface_material("MyMaterial", "MyMaterial2")
-
         """
         if not material.lower() in list(self.surface_material_keys.keys()):
-            self._messenger.add_error_message("Material {} is not present".format(material))
+            self.logger.error("Material {} is not present".format(material))
             return False
         newmat = SurfaceMaterial(self, new_name.lower(), self.surface_material_keys[material.lower()]._props)
         newmat.update()
@@ -394,6 +440,10 @@ class Materials(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oDefinitionManager.RemoveMaterial
 
         Examples
         --------
@@ -404,11 +454,12 @@ class Materials(object):
         >>> hfss.materials.remove_material("MyMaterial")
 
         """
-        if material not in list(self.material_keys.keys()):
-            self._messenger.add_error_message("Material {} is not present".format(material))
+        mat = material.lower()
+        if mat not in list(self.material_keys.keys()):
+            self.logger.error("Material {} is not present".format(mat))
             return False
-        self.odefinition_manager.RemoveMaterial(material, True, "", library)
-        del self.material_keys[material]
+        self.odefinition_manager.RemoveMaterial(mat, True, "", library)
+        del self.material_keys[mat]
         return True
 
     @property
@@ -434,7 +485,7 @@ class Materials(object):
         Returns
         -------
         list
-            List of dielctrics in the material database.
+            List of dielectrics in the material database.
 
         """
         data = []
@@ -450,13 +501,13 @@ class Materials(object):
                 try:
                     self._aedmattolibrary(el)
                 except Exception as e:
-                    self._messenger.add_info_message("aedmattolibrary failed for material {}".format(el))
+                    self.logger.info("aedmattolibrary failed for material %s", el)
 
     @aedt_exception_handler
     def _aedmattolibrary(self, matname):
         matname = matname.lower()
         props = {}
-        arg2dict(list(retry_ntimes(10, self.omaterial_manager.GetData, matname)), props)
+        _arg2dict(list(_retry_ntimes(20, self.omaterial_manager.GetData, matname)), props)
         values_view = props.values()
         value_iterator = iter(values_view)
         first_value = next(value_iterator)
@@ -465,6 +516,7 @@ class Materials(object):
         self.material_keys[matname] = newmat
         return True
 
+    @aedt_exception_handler
     def export_materials_to_file(self, full_json_path):
         """Export all materials to a JSON file.
 
@@ -500,8 +552,8 @@ class Materials(object):
         find_datasets(output_dict, out_list)
         datasets = OrderedDict()
         for ds in out_list:
-            if ds in list(self._parent.project_datasets.keys()):
-                d = self._parent.project_datasets[ds]
+            if ds in list(self._app.project_datasets.keys()):
+                d = self._app.project_datasets[ds]
                 if d.z:
                     datasets[ds] = OrderedDict(
                         {
@@ -528,11 +580,23 @@ class Materials(object):
         json_dict["materials"] = output_dict
         if datasets:
             json_dict["datasets"] = datasets
-
-        with open(full_json_path, "w") as fp:
-            json.dump(json_dict, fp, indent=4)
+        if not is_ironpython:
+            with open(full_json_path, "w") as fp:
+                json.dump(json_dict, fp, indent=4)
+        else:
+            temp_path = full_json_path.replace(".json", "_temp.json")
+            with open(temp_path, "w") as fp:
+                json.dump(json_dict, fp, indent=4)
+            with open(temp_path, "r") as file:
+                filedata = file.read()
+            filedata = filedata.replace("True", "true")
+            filedata = filedata.replace("False", "false")
+            with open(full_json_path, "w") as file:
+                file.write(filedata)
+            os.remove(temp_path)
         return True
 
+    @aedt_exception_handler
     def import_materials_from_file(self, full_json_path):
         """Import and create materials from a JSON file.
 
@@ -547,7 +611,7 @@ class Materials(object):
             ``True`` when successful, ``False`` when failed.
 
         """
-        with open(full_json_path) as json_file:
+        with open(full_json_path, "r") as json_file:
             data = json.load(json_file)
 
         if "datasets" in list(data.keys()):
@@ -567,14 +631,14 @@ class Materials(object):
                 if numcol > 2:
                     zunit = val["Coordinates"]["DimUnits"][2]
                     zval = new_list[2]
-                self._parent.create_dataset(
+                self._app.create_dataset(
                     el[1:], xunit=xunit, yunit=yunit, zunit=zunit, xlist=xval, ylist=yval, zlist=zval
                 )
 
         for el, val in data["materials"].items():
             if el.lower() in list(self.material_keys.keys()):
                 newname = generate_unique_name(el)
-                self._messenger.add_warning_message("Material {} already exists. Renaming to {}".format(el, newname))
+                self.logger.warning("Material %s already exists. Renaming to %s", el, newname)
             else:
                 newname = el
             newmat = Material(self, newname, val)
