@@ -6,8 +6,8 @@ This module provides all functionalities for creating and editing the mesh in th
 """
 from __future__ import absolute_import
 
-from ..generic.general_methods import aedt_exception_handler, generate_unique_name
-from ..generic.DataHandlers import dict2arg
+from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name
+from pyaedt.generic.DataHandlers import _dict2arg
 from collections import OrderedDict
 
 
@@ -16,7 +16,7 @@ class Mesh3DOperation(object):
 
     Parameters
     ----------
-    parent :
+    app :
 
     hfss_setup_name : str
         Name of the HFSS setup.
@@ -27,8 +27,8 @@ class Mesh3DOperation(object):
 
     """
 
-    def __init__(self, parent, hfss_setup_name, name, props):
-        self._parent = parent
+    def __init__(self, app, hfss_setup_name, name, props):
+        self._mesh3dlayout = app
         self.name = name
         self.props = props
         self.hfss_setup_name = hfss_setup_name
@@ -52,7 +52,7 @@ class Mesh3DOperation(object):
         if not props:
             props = self.props
         arg = ["NAME:" + self.name]
-        dict2arg(props, arg)
+        _dict2arg(props, arg)
         return arg
 
     @aedt_exception_handler
@@ -64,8 +64,12 @@ class Mesh3DOperation(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.AddMeshOperation
         """
-        self._parent.omeshmodule.AddMeshOperation(self.hfss_setup_name, self._get_args())
+        self._mesh3dlayout.omeshmodule.AddMeshOperation(self.hfss_setup_name, self._get_args())
         return True
 
     @aedt_exception_handler
@@ -77,8 +81,12 @@ class Mesh3DOperation(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.EditMeshOperation
         """
-        self._parent.omeshmodule.EditMeshOperation(self.hfss_setup_name, self.name, self._get_args())
+        self._mesh3dlayout.omeshmodule.EditMeshOperation(self.hfss_setup_name, self.name, self._get_args())
         return True
 
     @aedt_exception_handler
@@ -90,8 +98,12 @@ class Mesh3DOperation(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.DeleteMeshOperation
         """
-        self._parent.omeshmodule.DeleteMeshOperation(
+        self._mesh3dlayout.omeshmodule.DeleteMeshOperation(
             self.hfss_setup_name,
             self.name,
         )
@@ -99,7 +111,7 @@ class Mesh3DOperation(object):
         return True
 
 
-class Mesh(object):
+class Mesh3d(object):
     """Mesh class.
 
     This class provides the main AEDT mesh functionaility. The inherited class
@@ -107,43 +119,33 @@ class Mesh(object):
 
     Parameters
     ----------
-    parent :
+    app : :class:`pyaedt.application.Analysis3DLayout.FieldAnalysis3DLayout`
 
     """
 
-    def __init__(self, parent):
-        self._parent = parent
+    def __init__(self, app):
+        self._app = app
+
+        self.logger = self._app.logger
+        self._odesign = self._app._odesign
+        self.modeler = self._app._modeler
+        self._omeshmodule = self._odesign.GetModule("SolveSetups")
         self.id = 0
+
         self.meshoperations = self._get_design_mesh_operations()
 
         pass
 
     @property
     def omeshmodule(self):
-        """Mesh module.
+        """AEDT Mesh Module.
 
-        Returns
-        -------
-        type
-            Mesh module object.
+        References
+        ----------
+
+        >>> oDesign.GetModule("SolveSetups")
         """
-
-        return self.odesign.GetModule("SolveSetups")
-
-    @property
-    def _messenger(self):
-        """_messenger."""
-        return self._parent._messenger
-
-    @property
-    def odesign(self):
-        """Design."""
-        return self._parent._odesign
-
-    @property
-    def modeler(self):
-        """Modeler."""
-        return self._parent._modeler
+        return self._omeshmodule
 
     @aedt_exception_handler
     def delete_mesh_operations(self, setup_name, mesh_name):
@@ -161,6 +163,10 @@ class Mesh(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.DeleteMeshOperation
         """
         for el in self.meshoperations:
             if el.hfss_setup_name == setup_name and el.name == mesh_name:
@@ -181,10 +187,10 @@ class Mesh(object):
         """
         meshops = []
         try:
-            for ds in self._parent.design_properties["Setup"]["Data"]:
-                if "MeshOps" in self._parent.design_properties["Setup"]["Data"][ds]:
-                    for ops in self._parent.design_properties["Setup"]["Data"][ds]["MeshOps"]:
-                        props = self._parent.design_properties["Setup"]["Data"][ds]["MeshOps"][ops]
+            for ds in self._app.design_properties["Setup"]["Data"]:
+                if "MeshOps" in self._app.design_properties["Setup"]["Data"][ds]:
+                    for ops in self._app.design_properties["Setup"]["Data"][ds]["MeshOps"]:
+                        props = self._app.design_properties["Setup"]["Data"][ds]["MeshOps"][ops]
                         meshops.append(Mesh3DOperation(self, ds, ops, props))
         except:
             pass
@@ -220,6 +226,10 @@ class Mesh(object):
         type
             Mesh operation object.
 
+        References
+        ----------
+
+        >>> oModule.AddMeshOperation
         """
         if meshop_name:
             for el in self.meshoperations:
@@ -241,9 +251,9 @@ class Mesh(object):
             restrictel = True
             numel = str(maxel)
         if maxlength is None and maxel is None:
-            self._messenger.add_error_message("mesh not assigned due to incorrect settings")
+            self.logger.error("mesh not assigned due to incorrect settings")
             return
-        if type(layer_name) is list and type(net_name) is list:
+        if isinstance(layer_name, list) and isinstance(net_name, list):
             assignment = OrderedDict({"MeshEntityInfo": []})
             for l, n in zip(layer_name, net_name):
                 meshbody = OrderedDict({"Id": -1, "Nam": "", "Layer": l, "Net": n, "OrigNet": n})
@@ -316,6 +326,10 @@ class Mesh(object):
         type
             Mesh operation object.
 
+        References
+        ----------
+
+        >>> oModule.AddMeshOperation
         """
         if meshop_name:
             for el in self.meshoperations:
