@@ -1,8 +1,8 @@
 """This module contains these classes: `RMXprtModule` and `Rmxprt`."""
 from __future__ import absolute_import
 
-from .application.AnalysisRMxprt import FieldAnalysisRMxprt
-from .generic.general_methods import aedt_exception_handler
+from pyaedt.application.AnalysisRMxprt import FieldAnalysisRMxprt
+from pyaedt.generic.general_methods import aedt_exception_handler
 
 
 class RMXprtModule(object):
@@ -59,6 +59,10 @@ class RMXprtModule(object):
         bool
             ``True`` when successful, ``False`` when failed
 
+        References
+        ----------
+
+        >>> oEditor.ChangeProperty
         """
         prop_server = self.get_prop_server(parameter_name)
         separator = ":" if prop_server else ""
@@ -203,3 +207,13 @@ class Rmxprt(FieldAnalysisRMxprt):
 
     def __enter__(self):
         return self
+
+    @property
+    def design_type(self):
+        """Get/Set the Machine Design Type."""
+        return self.design_solutions.design_type
+
+    @design_type.setter
+    @aedt_exception_handler
+    def design_type(self, value):
+        self.design_solutions.design_type = value
